function [R,Z,f] = Perfilgauss(a,b,beta,delta)
%function [R,Z,f] = Perfilgauss(a,b,beta,delta) genera la curva del perfil de temperaturas doblemente gaussiano, en R y en Z.
%Los parametros que vamos a utilizar

%   a:         Hace referencia a la altura maxima del cilindro
%   b:         Hace referencia a la distancia radial maxima del sistema que vamos a estudiar
%   beta:      Parametro beta que modela el comportamiento gaussiano en la direccion radial que vamos a utilizar.
%   delta:     Parametro beta que modela el comportamiento gaussiano en la direccion Z que vamos a utilizar.

    i=1;k=1;
    
    for Z=-a:0.05:a
        for R=-b:0.05:b    
            f(k,i) = (1-exp(-(Z^2)/delta))*exp(-(R^2)/beta);
            i=i+1;
        end
        k=k+1;
        i=1;
    end

    
    %Veamos una representacion grafica del comportamiento del perfil de temperaturas.
    
    R=-b:0.05:b;
    Z=-a:0.05:a;
    surface(R,Z,f);xlabel('R');ylabel('Z');title('Temperatura adimensional en funcion de R y Z')